﻿Class ViewModel : Inherits NotifyPropertyChangedBaseClass

	Private ReadOnly Game As New Game
	Private ReadOnly RoundSummary As New RoundSummary

	Property ThrowDiceRelayCommand As New RelayCommand(AddressOf ThrowDice)
	Property SaveAndCloseRelayCommand As New RelayCommand(AddressOf SaveDataAndCloseWindow)

	ReadOnly Property PlayersRoundResult() As Integer
		Get
			Return RoundSummary.PlayerResult
		End Get
	End Property
	ReadOnly Property ComputersRoundResult As Integer
		Get
			Return RoundSummary.ComputerResult
		End Get
	End Property
	ReadOnly Property CountOfComputerVictories As Integer
		Get
			Return Game.ComputerVictoryCount
		End Get
	End Property
	ReadOnly Property CountOfPlayerVictories As Integer
		Get
			Return Game.PlayerVictoryCount
		End Get
	End Property
	ReadOnly Property CountOfDraws As Integer
		Get
			Return Game.DrawCount
		End Get
	End Property
	ReadOnly Property ComputerReaction As String
		Get
			Return RoundSummary.ComputerReaction
		End Get
	End Property

	Private _DialogResult As DialogResult
	Property DialogResult() As DialogResult
		Get
			Return _DialogResult
		End Get
		Private Set
			If Not ValueChanges(_DialogResult, Value) Then Return

			_DialogResult = Value
			OnPropertyChanged()
		End Set
	End Property

	Private ReadOnly GameFileContentManager As New GameFileContentManager("Ergebnisse.txt")

	Sub New()
		Game.LoadDataFrom(GameFileContentManager.GetGameStatisticsFromFile)
		AddHandler Game.DiceThrow, AddressOf Game_DiceThrow
	End Sub

	Private Sub ThrowDice()
		Game.ThrowDice()
	End Sub

	Private Sub Game_DiceThrow(sender As Object, e As DiceThrowingEventArgs)
		RoundSummary.RememberResults(e)
		OnPropertyChanged(NameOf(PlayersRoundResult))
		OnPropertyChanged(NameOf(ComputersRoundResult))
		OnPropertyChanged(NameOf(CountOfComputerVictories))
		OnPropertyChanged(NameOf(CountOfPlayerVictories))
		OnPropertyChanged(NameOf(CountOfDraws))
	End Sub

	Private Sub SaveDataAndCloseWindow()
		GameFileContentManager.WriteGameStatisticsToFile((Game.PlayerVictoryCount, Game.ComputerVictoryCount, Game.DrawCount))
		DialogResult = DialogResult.OK
	End Sub

End Class